// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.

#include "core/framework/data_types.h"

namespace onnxruntime {
namespace js {
std::vector<MLDataType>& JsepSupportedDataTypes();
std::vector<MLDataType>& JsepSupportedFloatTypes();
}  // namespace js
}  // namespace onnxruntime